@@ -32,6 +32,6 @@ async fn main() -> Result<()> {
     Toplevel::new()
         .start("Subsys1", |a| subsys.run(a))
         .catch_signals()
-        .wait_for_shutdown(Duration::from_millis(1000))
+        .handle_shutdown_requests(Duration::from_millis(1000))
         .await
 }
