@@ -9,7 +9,7 @@ use env_logger::{Builder, Env};
 use tokio::time::{sleep, Duration};
 use tokio_graceful_shutdown::{SubsystemHandle, Toplevel};
 
-async fn subsys1(mut subsys: SubsystemHandle) -> Result<()> {
+async fn subsys1(subsys: SubsystemHandle) -> Result<()> {
     subsys.start("Subsys2", subsys2);
     log::info!("Subsystem1 started.");
     subsys.on_shutdown_requested().await;
@@ -35,6 +35,6 @@ async fn main() -> Result<()> {
     Toplevel::new()
         .start("Subsys1", subsys1)
         .catch_signals()
-        .wait_for_shutdown(Duration::from_millis(1000))
+        .handle_shutdown_requests(Duration::from_millis(1000))
         .await
 }
