@@ -44,7 +44,7 @@ impl SubsystemHandle {
     ///     Ok(())
     /// }
     ///
-    /// async fn my_subsystem(mut subsys: SubsystemHandle) -> Result<()> {
+    /// async fn my_subsystem(subsys: SubsystemHandle) -> Result<()> {
     ///     // start a nested subsystem
     ///     subsys.start("Nested", nested_subsystem);
     ///
@@ -57,7 +57,7 @@ impl SubsystemHandle {
         Fut: 'static + Future<Output = Result<()>> + Send,
         S: 'static + FnOnce(SubsystemHandle) -> Fut + Send,
     >(
-        &mut self,
+        &self,
         name: &'static str,
         subsystem: S,
     ) -> NestedSubsystem {
@@ -83,6 +83,7 @@ impl SubsystemHandle {
         let subsystem_runner = SubsystemRunner::new(
             name,
             subsystem_handle.global_shutdown_token().clone(),
+            new_subsystem.local_shutdown_token.clone(),
             subsystem(subsystem_handle),
         );
 
@@ -188,7 +189,7 @@ impl SubsystemHandle {
     ///     Ok(())
     /// }
     ///
-    /// async fn subsystem(mut subsys: SubsystemHandle) -> Result<()> {
+    /// async fn subsystem(subsys: SubsystemHandle) -> Result<()> {
     ///     // This subsystem waits for one second and then performs a partial shutdown
     ///
     ///     // Spawn nested subsystem
