@@ -177,7 +177,7 @@ async fn nested_subsystem_receives_shutdown() {
         Ok(())
     };
 
-    let subsystem = |mut subsys: SubsystemHandle| async move {
+    let subsystem = |subsys: SubsystemHandle| async move {
         subsys.start("nested", nested_subsystem);
         subsys.on_shutdown_requested().await;
         Ok(())
@@ -209,7 +209,7 @@ async fn nested_subsystem_error_propagates() {
 
     let nested_subsystem = |_subsys: SubsystemHandle| async move { Err(anyhow!("Error!")) };
 
-    let subsystem = move |mut subsys: SubsystemHandle| async move {
+    let subsystem = move |subsys: SubsystemHandle| async move {
         subsys.start("nested", nested_subsystem);
         subsys.on_shutdown_requested().await;
         Ok(())
@@ -246,7 +246,7 @@ async fn panic_gets_handled_correctly() {
         panic!("Error!");
     };
 
-    let subsystem = move |mut subsys: SubsystemHandle| async move {
+    let subsystem = move |subsys: SubsystemHandle| async move {
         subsys.start("nested", nested_subsystem);
         subsys.on_shutdown_requested().await;
         Ok(())
@@ -386,7 +386,7 @@ async fn spawning_task_during_shutdown_causes_task_to_be_cancelled() {
         Ok(())
     };
 
-    let subsystem = move |mut subsys: SubsystemHandle| async move {
+    let subsystem = move |subsys: SubsystemHandle| async move {
         subsys.on_shutdown_requested().await;
         sleep(Duration::from_millis(100)).await;
         subsys.start("Nested", nested);
@@ -451,7 +451,7 @@ async fn double_panic_does_not_stop_graceful_shutdown() {
         panic!("Subsystem2 panicked!")
     };
 
-    let subsys1 = move |mut subsys: SubsystemHandle| async move {
+    let subsys1 = move |subsys: SubsystemHandle| async move {
         subsys.start("Subsys2", subsys2);
         subsys.start("Subsys3", subsys3);
         subsys.on_shutdown_requested().await;
@@ -539,7 +539,7 @@ async fn partial_shutdown_request_stops_nested_subsystems() {
         set_subsys3_finished();
         Ok(())
     };
-    let subsys2 = move |mut subsys: SubsystemHandle| async move {
+    let subsys2 = move |subsys: SubsystemHandle| async move {
         set_subsys2_started();
         subsys.start("subsys3", subsys3);
         subsys.on_shutdown_requested().await;
@@ -547,7 +547,7 @@ async fn partial_shutdown_request_stops_nested_subsystems() {
         Ok(())
     };
 
-    let subsys1 = move |mut subsys: SubsystemHandle| async move {
+    let subsys1 = move |subsys: SubsystemHandle| async move {
         set_subsys1_started();
         let nested_subsys = subsys.start("subsys2", subsys2);
         sleep(Duration::from_millis(200)).await;
@@ -600,7 +600,7 @@ async fn partial_shutdown_panic_gets_propagated_correctly() {
         panic!("Nested panicked.");
     };
 
-    let subsys1 = move |mut subsys: SubsystemHandle| async move {
+    let subsys1 = move |subsys: SubsystemHandle| async move {
         let handle = subsys.start("nested", nested_subsys);
         sleep(Duration::from_millis(100)).await;
         let result = subsys.perform_partial_shutdown(handle).await;
@@ -608,6 +608,7 @@ async fn partial_shutdown_panic_gets_propagated_correctly() {
         assert_eq!(result.err(), Some(PartialShutdownError::SubsystemFailed));
         assert!(nested_started.get());
         assert!(nested_finished.get());
+        assert!(!subsys.local_shutdown_token().is_shutting_down());
 
         subsys.request_shutdown();
         Ok(())
@@ -635,7 +636,7 @@ async fn partial_shutdown_error_gets_propagated_correctly() {
         Err(anyhow!("nested failed."))
     };
 
-    let subsys1 = move |mut subsys: SubsystemHandle| async move {
+    let subsys1 = move |subsys: SubsystemHandle| async move {
         let handle = subsys.start("nested", nested_subsys);
         sleep(Duration::from_millis(100)).await;
         let result = subsys.perform_partial_shutdown(handle).await;
@@ -643,6 +644,7 @@ async fn partial_shutdown_error_gets_propagated_correctly() {
         assert_eq!(result.err(), Some(PartialShutdownError::SubsystemFailed));
         assert!(nested_started.get());
         assert!(nested_finished.get());
+        assert!(!subsys.local_shutdown_token().is_shutting_down());
 
         subsys.request_shutdown();
         Ok(())
@@ -670,7 +672,7 @@ async fn partial_shutdown_during_program_shutdown_causes_error() {
         Ok(())
     };
 
-    let subsys1 = move |mut subsys: SubsystemHandle| async move {
+    let subsys1 = move |subsys: SubsystemHandle| async move {
         let handle = subsys.start("nested", nested_subsys);
         sleep(Duration::from_millis(100)).await;
 
@@ -713,7 +715,7 @@ async fn partial_shutdown_on_wrong_parent_causes_error() {
         Ok(())
     };
 
-    let subsys1 = move |mut subsys: SubsystemHandle| async move {
+    let subsys1 = move |subsys: SubsystemHandle| async move {
         let handle = subsys.start("nested", nested_subsys);
 
         sleep(Duration::from_millis(100)).await;
@@ -746,6 +748,68 @@ async fn partial_shutdown_on_wrong_parent_causes_error() {
     assert!(result.is_ok());
 }
 
+#[tokio::test]
+async fn cloned_handles_can_spawn_nested_subsystems() {
+    setup();
+
+    let (toplevel_finished, set_toplevel_finished) = Event::create();
+    let (subsys_finished, set_subsys_finished) = Event::create();
+    let (nested1_finished, set_nested1_finished) = Event::create();
+    let (nested2_finished, set_nested2_finished) = Event::create();
+
+    let nested_subsystem1 = |subsys: SubsystemHandle| async move {
+        subsys.on_shutdown_requested().await;
+        set_nested1_finished();
+        Ok(())
+    };
+
+    let nested_subsystem2 = |subsys: SubsystemHandle| async move {
+        subsys.on_shutdown_requested().await;
+        set_nested2_finished();
+        Ok(())
+    };
+
+    let subsystem = move |subsys: SubsystemHandle| async move {
+        let subsys_clone = subsys.clone();
+        subsys.start("nested1", nested_subsystem1);
+        subsys_clone.start("nested2", nested_subsystem2);
+        subsys_clone.on_shutdown_requested().await;
+        set_subsys_finished();
+        Ok(())
+    };
+
+    let toplevel = Toplevel::new().start("subsys", subsystem);
+    let shutdown_token = toplevel.get_shutdown_token().clone();
+
+    tokio::join!(
+        async {
+            let result = toplevel
+                .handle_shutdown_requests(Duration::from_millis(200))
+                .await;
+            set_toplevel_finished();
+            // Assert panic causes Error propagation to Toplevel
+            assert!(result.is_ok());
+        },
+        async {
+            // Assert that subsystems don't shut down prematurely
+            sleep(Duration::from_millis(100)).await;
+            assert!(!subsys_finished.get());
+            assert!(!nested1_finished.get());
+            assert!(!nested2_finished.get());
+            assert!(!toplevel_finished.get());
+
+            shutdown_token.shutdown();
+            sleep(Duration::from_millis(100)).await;
+            // Assert subsystems did shut down properly
+            assert!(subsys_finished.get());
+            assert!(nested1_finished.get());
+            assert!(nested2_finished.get());
+            assert!(toplevel_finished.get());
+            assert!(shutdown_token.is_shutting_down());
+        },
+    );
+}
+
 #[cfg(unix)]
 #[tokio::test]
 async fn shutdown_through_signal() {
